"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
/*
    emit.ts - Test basic emit functionality
 */
const init_1 = require("./utils/init");
jest.setTimeout(7200 * 1000);
test('Test basic emit', async () => {
    let metrics = new init_1.CustomMetrics({ client: init_1.client, table: init_1.table, owner: 'service', log: true });
    let timestamp = new Date(2000, 0, 1).getTime();
    let metric = await metrics.emit('test/emit', 'FirstMetric', 10, [], { timestamp });
    expect(metric).toBeDefined();
    expect(metric.namespace).toBe('test/emit');
    expect(metric.metric).toBe('FirstMetric');
    expect(metric.owner).toBe('service');
    expect(metric.spans.length).toBe(init_1.DefaultSpans.length);
    expect(metric.version).toBe(1);
    expect(metric.expires).toBeDefined();
    let span = metric.spans[0];
    let points = span.points;
    expect(points.length).toBe(1);
    expect(span.samples).toBe(init_1.DefaultSpans[0].samples);
    expect(span.period).toBe(init_1.DefaultSpans[0].period);
    expect(points[0].count).toBe(1);
    expect(points[0].sum).toBe(10);
    expect(points[0].max).toBe(10);
    expect(points[0].min).toBe(10);
    /*
        Query to ensure results are committed
     */
    let r = await metrics.query('test/emit', 'FirstMetric', {}, 300, 'sum', { timestamp });
    expect(r).toBeDefined();
    expect(r.metric).toBe('FirstMetric');
    expect(r.namespace).toBe('test/emit');
    expect(r.period).toBe(300);
    expect(r.points).toBeDefined();
    expect(r.points.length).toBe(1);
    expect(r.points[0].value).toBe(10);
    expect(r.points[0].count).toBe(1);
    expect(r.points[0].timestamp).toBe(timestamp);
});
test('Test emit with dimensions', async () => {
    let metrics = new init_1.CustomMetrics({ client: init_1.client, table: init_1.table, log: true });
    await metrics.emit('test/emit', 'Launches', 10, [{}, { Rocket: 'SaturnV' }]);
    await metrics.emit('test/emit', 'Launches', 10, [{}, { Rocket: 'Falcon9' }]);
    /*
        Query total launches
     */
    let r = await metrics.query('test/emit', 'Launches', {}, 300, 'sum');
    expect(r).toBeDefined();
    expect(r.dimensions).toBeDefined();
    expect(Object.keys(r.dimensions).length).toBe(0);
    expect(r.points.length).toBe(1);
    expect(r.points[0].value).toBe(20);
    expect(r.points[0].count).toBe(2);
    //  Query just one dimension
    r = await metrics.query('test/emit', 'Launches', { Rocket: 'Falcon9' }, 300, 'sum');
    expect(r).toBeDefined();
    expect(r.dimensions).toBeDefined();
    expect(r.dimensions.Rocket).toBe('Falcon9');
    expect(r.points.length).toBe(1);
    expect(r.points[0].value).toBe(10);
    expect(r.points[0].count).toBe(1);
    //  Query unknown dimension
    r = await metrics.query('test/emit', 'Launches', { Rocket: 'Starship' }, 300, 'sum');
    expect(r).toBeDefined();
    expect(r.dimensions).toBeDefined();
    expect(r.dimensions.Rocket).toBe('Starship');
    expect(r.points.length).toBe(0);
});
test('Emit Series', async () => {
    let metrics = new init_1.CustomMetrics({ client: init_1.client, table: init_1.table });
    let timestamp = new Date(2000, 0, 1).getTime();
    let span = init_1.DefaultSpans[0];
    let interval = span.period / span.samples;
    let metric;
    for (let i = 0; i < span.samples; i++) {
        metric = await metrics.emit('test/emit', 'SeriesMetric', i, [], { timestamp });
        metric = await metrics.emit('test/emit', 'SeriesMetric', i, [], { timestamp: timestamp + 1 });
        timestamp += interval * 1000;
    }
    let r = await metrics.query('test/emit', 'SeriesMetric', {}, 300, 'sum', { timestamp });
    expect(r).toBeDefined();
    expect(r.metric).toBe('SeriesMetric');
    expect(r.namespace).toBe('test/emit');
    expect(r.period).toBe(300);
    expect(r.points).toBeDefined();
    expect(r.points.length).toBe(10);
});
test('Emit API', async () => {
    let metrics = new init_1.CustomMetrics({ client: init_1.client, table: init_1.table });
    expect(async () => {
        await metrics.emit('test/emit', 'Launches', null);
    }).rejects.toThrow();
    expect(async () => {
        await metrics.emit('test/emit', 'Launches', undefined);
    }).rejects.toThrow();
    expect(async () => {
        await metrics.emit('test/emit', 'Launches', 'invalid');
    }).rejects.toThrow();
    expect(async () => {
        await metrics.emit(null, 'Launches', 10);
    }).rejects.toThrow();
    expect(async () => {
        await metrics.emit('namespace', null, 10);
    }).rejects.toThrow();
    //  Emit with ttl
    await metrics.emit('test/emit', 'ShortLived', 10, [], { ttl: 3600 });
});
